@@ -6,7 +6,7 @@ use alloc::{
     vec,
     vec::Vec,
 };
-use core::{convert, fmt, mem, ops::Range, str};
+use core::{fmt, mem, ops::Range, str};
 #[cfg(feature = "std")]
 use std::borrow::Cow;
 
@@ -14,8 +14,7 @@ use hmac::Hmac;
 use sha2::{Digest, Sha256, Sha512};
 use zeroize::Zeroize;
 
-use crate::error::Error;
-use crate::language::Language;
+use crate::{error::Error, language::Language};
 
 const BITS_PER_WORD: usize = 11;
 const BITS_PER_BYTE: usize = 8;
@@ -66,7 +65,7 @@ impl From<Count> for usize {
     }
 }
 
-impl convert::TryFrom<usize> for Count {
+impl TryFrom<usize> for Count {
     type Error = Error;
 
     fn try_from(count: usize) -> Result<Self, Self::Error> {
